@@ -108,6 +108,7 @@ def plot_single_def(plot,
                     logistic,
                     lowess,
                     robust,
+                    regplot_logx,
                     x_partial,
                     y_partial,
                     truncate,
@@ -139,7 +140,9 @@ def plot_single_def(plot,
                     treemaps_pad, 
                     bar_kwargs, 
                     text_kwargs,
-                    bubble_spacing): #disini default kalau nilai khusus plotnya none diganti default seaborn per plot
+                    bubble_spacing,
+                    showmeans, 
+                    meanprops):
     # relational plot family
     if plot == 'scatterplot':
         if x is not None or y is not None:
@@ -534,7 +537,7 @@ def plot_single_def(plot,
         else:
             pass
         if center is None:
-            center = (0, 0)
+            center = [0, 0]
         else:
             pass
         if frame is None:
@@ -641,6 +644,10 @@ def plot_single_def(plot,
                 jitter = True
             else:
                 pass
+            if dodge is None:
+                dodge = False
+            else:
+                pass
             if size is None:
                 size = 5
             else:
@@ -676,6 +683,10 @@ def plot_single_def(plot,
     elif plot == 'swarmplot':
         if x is not None or y is not None:
             # default value
+            if dodge is None:
+                dodge = False
+            else:
+                pass
             if size is None:
                 size = 5
             else:
@@ -730,6 +741,16 @@ def plot_single_def(plot,
                 whis = 1.5
             else:
                 pass
+            if showmeans is None:
+                showmeans = False
+            else:
+                pass
+            if meanprops is None:
+                meanprops = {'marker':'s',
+                             'markerfacecolor':'white', 
+                             'markeredgecolor':'.3'}
+            else:
+                pass
             # plot
             sns.boxplot(x=x, 
                         y=y, 
@@ -746,6 +767,8 @@ def plot_single_def(plot,
                         fliersize=fliersize, 
                         linewidth=linewidth, 
                         whis=whis, 
+                        showmeans=showmeans,
+                        meanprops=meanprops,
                         ax=ax,
                         zorder=zorder)
         else:
@@ -773,10 +796,6 @@ def plot_single_def(plot,
                 width = 0.8
             else:
                 pass
-            if inner is None:
-                inner = 'box'
-            else:
-                pass
             if split is None:
                 split = False
             else:
@@ -811,7 +830,6 @@ def plot_single_def(plot,
                            palette=palette, 
                            saturation=saturation, 
                            ax=ax,
-                           alpha=alpha,
                            zorder=zorder)
         else:
             raise Exception('Define axis label!')
@@ -923,7 +941,6 @@ def plot_single_def(plot,
                               errwidth=errwidth, 
                               capsize=capsize, 
                               ax=ax,
-                              alpha=alpha,
                               zorder=zorder)
             else:
                 sns.pointplot(x=x, 
@@ -948,17 +965,12 @@ def plot_single_def(plot,
                               errwidth=errwidth, 
                               capsize=capsize, 
                               ax=ax,
-                              alpha=alpha,
                               zorder=zorder)
         else:
             raise Exception('Define axis label!')
     elif plot == 'barplot':
         if x is not None or y is not None:
             # default value
-            if ci is None:
-                ci = 95
-            else:
-                pass
             if n_boot is None:
                 n_boot = 1000
             else:
@@ -1038,6 +1050,10 @@ def plot_single_def(plot,
                 saturation = 0.75
             else:
                 pass
+            if dodge is None:
+                dodge = True
+            else:
+                pass
             sns.countplot(x=x, 
                           y=y, 
                           hue=hue, 
@@ -1063,10 +1079,6 @@ def plot_single_def(plot,
                 sorting_formula = numpy.flip(data_pareto_y.argsort())
                 data_pareto_x, data_pareto_y = data_pareto_x[sorting_formula], data_pareto_y[sorting_formula]
                 # default value
-                if ci is None:
-                    ci = 95
-                else:
-                    pass
                 if n_boot is None:
                     n_boot = 1000
                 else:
@@ -1165,10 +1177,6 @@ def plot_single_def(plot,
                 sorting_formula = numpy.flip(data_pareto_x.argsort())
                 data_pareto_x, data_pareto_y = data_pareto_x[sorting_formula], data_pareto_y[sorting_formula]
                 # default value
-                if ci is None:
-                    ci = 95
-                else:
-                    pass
                 if n_boot is None:
                     n_boot = 1000
                 else:
@@ -1268,10 +1276,6 @@ def plot_single_def(plot,
     elif plot == 'regplot':
         if x is not None or y is not None:
             # default value
-            if x_ci is None:
-                x_ci = 'ci'
-            else:
-                pass
             if scatter is None:
                 scatter = True
             else:
@@ -1280,10 +1284,6 @@ def plot_single_def(plot,
                 fit_reg = True
             else:
                 pass
-            if ci is None:
-                ci = 95
-            else:
-                pass
             if n_boot is None:
                 n_boot = 1000
             else:
@@ -1304,6 +1304,10 @@ def plot_single_def(plot,
                 robust = False
             else:
                 pass
+            if regplot_logx is None:
+                regplot_logx = False
+            else:
+                pass
             if truncate is None:
                 truncate = True
             else:
@@ -1333,7 +1337,7 @@ def plot_single_def(plot,
                         logistic=logistic, 
                         lowess=lowess, 
                         robust=robust, 
-                        logx=False, 
+                        logx=regplot_logx, 
                         x_partial=x_partial, 
                         y_partial=y_partial, 
                         truncate=truncate, 
@@ -1345,9 +1349,7 @@ def plot_single_def(plot,
                         marker=marker, 
                         scatter_kws=scatter_kws, 
                         line_kws=line_kws, 
-                        ax=ax,
-                        alpha=alpha,
-                        zorder=zorder)
+                        ax=ax)
         else:
             raise Exception('Define axis label!')
     elif plot == 'residplot':
@@ -1383,9 +1385,7 @@ def plot_single_def(plot,
                           color=color, 
                           scatter_kws=scatter_kws, 
                           line_kws=line_kws, 
-                          ax=ax,
-                          alpha=alpha,
-                          zorder=zorder)
+                          ax=ax)
         else:
             raise Exception('Define axis label!')
     else:
